==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1CustomResourceDefinitionStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1CustomResourceDefinitionStatusFluent<A extends V1beta1CustomResourceDefinitionStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAcceptedNames instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1CustomResourceDefinitionNames getAcceptedNames();
    public V1beta1CustomResourceDefinitionNames buildAcceptedNames();
    public A withAcceptedNames(V1beta1CustomResourceDefinitionNames acceptedNames);
    public Boolean hasAcceptedNames();
    public V1beta1CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> withNewAcceptedNames();
    public V1beta1CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> withNewAcceptedNamesLike(V1beta1CustomResourceDefinitionNames item);
    public V1beta1CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editAcceptedNames();
    public V1beta1CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editOrNewAcceptedNames();
    public V1beta1CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editOrNewAcceptedNamesLike(V1beta1CustomResourceDefinitionNames item);
    public A addToConditions(int index,V1beta1CustomResourceDefinitionCondition item);
    public A setToConditions(int index,V1beta1CustomResourceDefinitionCondition item);
    public A addToConditions(V1beta1CustomResourceDefinitionCondition... items);
    public A addAllToConditions(Collection<V1beta1CustomResourceDefinitionCondition> items);
    public A removeFromConditions(V1beta1CustomResourceDefinitionCondition... items);
    public A removeAllFromConditions(Collection<V1beta1CustomResourceDefinitionCondition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1CustomResourceDefinitionCondition> getConditions();
    public List<V1beta1CustomResourceDefinitionCondition> buildConditions();
    public V1beta1CustomResourceDefinitionCondition buildCondition(int index);
    public V1beta1CustomResourceDefinitionCondition buildFirstCondition();
    public V1beta1CustomResourceDefinitionCondition buildLastCondition();
    public V1beta1CustomResourceDefinitionCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1CustomResourceDefinitionConditionBuilder> predicate);
    public A withConditions(List<V1beta1CustomResourceDefinitionCondition> conditions);
    public A withConditions(V1beta1CustomResourceDefinitionCondition... conditions);
    public Boolean hasConditions();
    public V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<A> addNewCondition();
    public V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<A> addNewConditionLike(V1beta1CustomResourceDefinitionCondition item);
    public V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<A> setNewConditionLike(int index,V1beta1CustomResourceDefinitionCondition item);
    public V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<A> editCondition(int index);
    public V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<A> editFirstCondition();
    public V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<A> editLastCondition();
    public V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1CustomResourceDefinitionConditionBuilder> predicate);
    public A addToStoredVersions(int index,String item);
    public A setToStoredVersions(int index,String item);
    public A addToStoredVersions(String... items);
    public A addAllToStoredVersions(Collection<String> items);
    public A removeFromStoredVersions(String... items);
    public A removeAllFromStoredVersions(Collection<String> items);
    public List<String> getStoredVersions();
    public String getStoredVersion(int index);
    public String getFirstStoredVersion();
    public String getLastStoredVersion();
    public String getMatchingStoredVersion(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withStoredVersions(List<String> storedVersions);
    public A withStoredVersions(String... storedVersions);
    public Boolean hasStoredVersions();

    public interface AcceptedNamesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CustomResourceDefinitionNamesFluent<V1beta1CustomResourceDefinitionStatusFluent.AcceptedNamesNested<N>>{

        
    public N and();    public N endAcceptedNames();
}
    public interface ConditionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CustomResourceDefinitionConditionFluent<V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1CustomResourceDefinitionStatusFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1CustomResourceDefinitionStatusFluent<A extends V1beta1CustomResourceDefinitionStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAcceptedNames instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1CustomResourceDefinitionNames getAcceptedNames();
    public V1beta1CustomResourceDefinitionNames buildAcceptedNames();
    public A withAcceptedNames(V1beta1CustomResourceDefinitionNames acceptedNames);
    public Boolean hasAcceptedNames();
    public V1beta1CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> withNewAcceptedNames();
    public V1beta1CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> withNewAcceptedNamesLike(V1beta1CustomResourceDefinitionNames item);
    public V1beta1CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editAcceptedNames();
    public V1beta1CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editOrNewAcceptedNames();
    public V1beta1CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editOrNewAcceptedNamesLike(V1beta1CustomResourceDefinitionNames item);
    public A addToConditions(int index,V1beta1CustomResourceDefinitionCondition item);
    public A setToConditions(int index,V1beta1CustomResourceDefinitionCondition item);
    public A addToConditions(V1beta1CustomResourceDefinitionCondition... items);
    public A addAllToConditions(Collection<V1beta1CustomResourceDefinitionCondition> items);
    public A removeFromConditions(V1beta1CustomResourceDefinitionCondition... items);
    public A removeAllFromConditions(Collection<V1beta1CustomResourceDefinitionCondition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1CustomResourceDefinitionCondition> getConditions();
    public List<V1beta1CustomResourceDefinitionCondition> buildConditions();
    public V1beta1CustomResourceDefinitionCondition buildCondition(int index);
    public V1beta1CustomResourceDefinitionCondition buildFirstCondition();
    public V1beta1CustomResourceDefinitionCondition buildLastCondition();
    public V1beta1CustomResourceDefinitionCondition buildMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1CustomResourceDefinitionConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1CustomResourceDefinitionConditionBuilder> predicate);
    public A withConditions(List<V1beta1CustomResourceDefinitionCondition> conditions);
    public A withConditions(V1beta1CustomResourceDefinitionCondition... conditions);
    public Boolean hasConditions();
    public V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<A> addNewCondition();
    public V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<A> addNewConditionLike(V1beta1CustomResourceDefinitionCondition item);
    public V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<A> setNewConditionLike(int index,V1beta1CustomResourceDefinitionCondition item);
    public V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<A> editCondition(int index);
    public V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<A> editFirstCondition();
    public V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<A> editLastCondition();
    public V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<A> editMatchingCondition(io.kubernetes.client.fluent.Predicate<V1beta1CustomResourceDefinitionConditionBuilder> predicate);
    public A addToStoredVersions(int index,String item);
    public A setToStoredVersions(int index,String item);
    public A addToStoredVersions(String... items);
    public A addAllToStoredVersions(Collection<String> items);
    public A removeFromStoredVersions(String... items);
    public A removeAllFromStoredVersions(Collection<String> items);
    public List<String> getStoredVersions();
    public String getStoredVersion(int index);
    public String getFirstStoredVersion();
    public String getLastStoredVersion();
    public String getMatchingStoredVersion(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingStoredVersion(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withStoredVersions(List<String> storedVersions);
    public A withStoredVersions(String... storedVersions);
    public Boolean hasStoredVersions();
    public A addNewStoredVersion(String arg1);
    public A addNewStoredVersion(StringBuilder arg1);
    public A addNewStoredVersion(StringBuffer arg1);

    public interface AcceptedNamesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CustomResourceDefinitionNamesFluent<V1beta1CustomResourceDefinitionStatusFluent.AcceptedNamesNested<N>>{

        
    public N and();    public N endAcceptedNames();
}
    public interface ConditionsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1CustomResourceDefinitionConditionFluent<V1beta1CustomResourceDefinitionStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}
